.. _internals:

===========
 Internals
===========

:Release: |version|
:Date: |today|

.. toctree::
    :maxdepth: 2

    guide
    deprecation
    worker
    protocol
    protov2
    app-overview
    reference/index
